==> jc-1.4.0.tar.gz: javax/swing/JColorChooser__24ModalDialog.h <==
// class javax.swing.JColorChooser$ModalDialog

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 6a0159196eecd68 java_awt_Dialog
// @dep_class 184d12f43c3697c9 java_awt_Window
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6addc37516d69588 javax_swing_JColorChooser__24ModalDialog
// @dep_class 76e1edcd9530dc7e javax_swing_JDialog

// header file dependencies
// @dep_header javax_swing_JDialog

#include "javax/swing/JDialog.h"

#ifndef _JC_javax_swing_JColorChooser__24ModalDialog_H_
#define _JC_javax_swing_JColorChooser__24ModalDialog_H_

// Forward structure declarations
struct _jc_java_awt_Dialog$object;
struct _jc_java_awt_Frame$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_JColorChooser__24ModalDialog$sub_refs	_jc_javax_swing_JColorChooser__24ModalDialog$sub_refs;
typedef struct _jc_javax_swing_JColorChooser__24ModalDialog$sub_nonrefs	_jc_javax_swing_JColorChooser__24ModalDialog$sub_nonrefs;
typedef struct _jc_javax_swing_JColorChooser__24ModalDialog$refs	_jc_javax_swing_JColorChooser__24ModalDialog$refs;
typedef struct _jc_javax_swing_JColorChooser__24ModalDialog$nonrefs	_jc_javax_swing_JColorChooser__24ModalDialog$nonrefs;
typedef struct _jc_javax_swing_JColorChooser__24ModalDialog$object	_jc_javax_swing_JColorChooser__24ModalDialog$object;

typedef const struct _jc_javax_swing_JColorChooser__24ModalDialog$vmethods	_jc_javax_swing_JColorChooser__24ModalDialog$vmethods;
typedef const struct _jc_javax_swing_JColorChooser__24ModalDialog$vtable	_jc_javax_swing_JColorChooser__24ModalDialog$vtable;
typedef const struct _jc_javax_swing_JColorChooser__24ModalDialog$vtype	_jc_javax_swing_JColorChooser__24ModalDialog$vtype;

// Constructors
extern void _jc_javax_swing_JColorChooser__24ModalDialog$method$_init$ed02ac6a415c0920(_jc_env *, struct _jc_javax_swing_JColorChooser__24ModalDialog$object *, struct _jc_java_awt_Dialog$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_swing_JColorChooser__24ModalDialog$method$_init$dd16da5f23be2562(_jc_env *, struct _jc_javax_swing_JColorChooser__24ModalDialog$object *, struct _jc_java_awt_Frame$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_javax_swing_JColorChooser__24ModalDialog$method$hide$048a3beb9ae7da95(_jc_env *, struct _jc_javax_swing_JColorChooser__24ModalDialog$object *);
extern void _jc_javax_swing_JColorChooser__24ModalDialog$method$setModal$cfac6d823f8d7de5(_jc_env *, struct _jc_javax_swing_JColorChooser__24ModalDialog$object *, jboolean);
extern void _jc_javax_swing_JColorChooser__24ModalDialog$method$show$8844e066fe447d0e(_jc_env *, struct _jc_javax_swing_JColorChooser__24ModalDialog$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JColorChooser__24ModalDialog$method_info$hide$048a3beb9ae7da95;
extern _jc_method _jc_javax_swing_JColorChooser__24ModalDialog$method_info$setModal$cfac6d823f8d7de5;
extern _jc_method _jc_javax_swing_JColorChooser__24ModalDialog$method_info$show$8844e066fe447d0e;

// Virtual methods structure
struct _jc_javax_swing_JColorChooser__24ModalDialog$vmethods {
	void	(*hide$048a3beb9ae7da95)(_jc_env *, struct _jc_javax_swing_JColorChooser__24ModalDialog$object *);
	void	(*setModal$cfac6d823f8d7de5)(_jc_env *, struct _jc_javax_swing_JColorChooser__24ModalDialog$object *, jboolean);
	void	(*show$8844e066fe447d0e)(_jc_env *, struct _jc_javax_swing_JColorChooser__24ModalDialog$object *);
};

// Vtable
struct _jc_javax_swing_JColorChooser__24ModalDialog$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_java_awt_Window$vmethods	java_awt_Window;
	_jc_java_awt_Dialog$vmethods	java_awt_Dialog;
	_jc_javax_swing_JDialog$vmethods	javax_swing_JDialog;
	_jc_javax_swing_JColorChooser__24ModalDialog$vmethods	javax_swing_JColorChooser__24ModalDialog;
};

// Vtype
struct _jc_javax_swing_JColorChooser__24ModalDialog$vtype {
	_jc_type			type;
	_jc_javax_swing_JColorChooser__24ModalDialog$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JColorChooser__24ModalDialog$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_JColorChooser__24ModalDialog$refs {
    _jc_javax_swing_JColorChooser__24ModalDialog$sub_refs	javax_swing_JColorChooser__24ModalDialog;
    _jc_javax_swing_JDialog$sub_refs	javax_swing_JDialog;
    _jc_java_awt_Dialog$sub_refs	java_awt_Dialog;
    _jc_java_awt_Window$sub_refs	java_awt_Window;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JColorChooser__24ModalDialog$sub_nonrefs {
	jboolean	modal;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JColorChooser__24ModalDialog$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_java_awt_Window$sub_nonrefs	java_awt_Window;
    _jc_java_awt_Dialog$sub_nonrefs	java_awt_Dialog;
    _jc_javax_swing_JDialog$sub_nonrefs	javax_swing_JDialog;
    _jc_javax_swing_JColorChooser__24ModalDialog$sub_nonrefs	javax_swing_JColorChooser__24ModalDialog;
};

// Object instance structure
struct _jc_javax_swing_JColorChooser__24ModalDialog$object {
	_jc_javax_swing_JColorChooser__24ModalDialog$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JColorChooser__24ModalDialog$vtype	*vtype;
	_jc_javax_swing_JColorChooser__24ModalDialog$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JColorChooser__24ModalDialog$vtype _jc_javax_swing_JColorChooser__24ModalDialog$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JColorChooser__24ModalDialog, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JColorChooser__24ModalDialog$class_object;

#endif	/* _JC_javax_swing_JColorChooser__24ModalDialog_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JColorChooser__24ModalDialog.h <==
// class javax.swing.JColorChooser$ModalDialog

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 6a0159196eecd68 java_awt_Dialog
// @dep_class fd4ae025aa56ceb9 java_awt_Window
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ccf94cd02e7192da javax_swing_JColorChooser__24ModalDialog
// @dep_class 76e1edcd9530dc7e javax_swing_JDialog

// header file dependencies
// @dep_header javax_swing_JDialog

#include "javax/swing/JDialog.h"

#ifndef _JC_javax_swing_JColorChooser__24ModalDialog_H_
#define _JC_javax_swing_JColorChooser__24ModalDialog_H_

// Forward structure declarations
struct _jc_java_awt_Dialog$object;
struct _jc_java_awt_Frame$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_JColorChooser__24ModalDialog$sub_refs	_jc_javax_swing_JColorChooser__24ModalDialog$sub_refs;
typedef struct _jc_javax_swing_JColorChooser__24ModalDialog$sub_nonrefs	_jc_javax_swing_JColorChooser__24ModalDialog$sub_nonrefs;
typedef struct _jc_javax_swing_JColorChooser__24ModalDialog$refs	_jc_javax_swing_JColorChooser__24ModalDialog$refs;
typedef struct _jc_javax_swing_JColorChooser__24ModalDialog$nonrefs	_jc_javax_swing_JColorChooser__24ModalDialog$nonrefs;
typedef struct _jc_javax_swing_JColorChooser__24ModalDialog$object	_jc_javax_swing_JColorChooser__24ModalDialog$object;

typedef const struct _jc_javax_swing_JColorChooser__24ModalDialog$vmethods	_jc_javax_swing_JColorChooser__24ModalDialog$vmethods;
typedef const struct _jc_javax_swing_JColorChooser__24ModalDialog$vtable	_jc_javax_swing_JColorChooser__24ModalDialog$vtable;
typedef const struct _jc_javax_swing_JColorChooser__24ModalDialog$vtype	_jc_javax_swing_JColorChooser__24ModalDialog$vtype;

// Constructors
extern void _jc_javax_swing_JColorChooser__24ModalDialog$method$_init$ed02ac6a415c0920(_jc_env *, struct _jc_javax_swing_JColorChooser__24ModalDialog$object *, struct _jc_java_awt_Dialog$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JColorChooser__24ModalDialog$method$_init$dd16da5f23be2562(_jc_env *, struct _jc_javax_swing_JColorChooser__24ModalDialog$object *, struct _jc_java_awt_Frame$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_JColorChooser__24ModalDialog$method$hide$048a3beb9ae7da95(_jc_env *, struct _jc_javax_swing_JColorChooser__24ModalDialog$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JColorChooser__24ModalDialog$method$setModal$cfac6d823f8d7de5(_jc_env *, struct _jc_javax_swing_JColorChooser__24ModalDialog$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JColorChooser__24ModalDialog$method$show$8844e066fe447d0e(_jc_env *, struct _jc_javax_swing_JColorChooser__24ModalDialog$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JColorChooser__24ModalDialog$method_info$hide$048a3beb9ae7da95;
extern _jc_method _jc_javax_swing_JColorChooser__24ModalDialog$method_info$setModal$cfac6d823f8d7de5;
extern _jc_method _jc_javax_swing_JColorChooser__24ModalDialog$method_info$show$8844e066fe447d0e;

// Virtual methods structure
struct _jc_javax_swing_JColorChooser__24ModalDialog$vmethods {
	void	(*hide$048a3beb9ae7da95)(_jc_env *, struct _jc_javax_swing_JColorChooser__24ModalDialog$object *) _JC_JCNI_ATTR;
	void	(*setModal$cfac6d823f8d7de5)(_jc_env *, struct _jc_javax_swing_JColorChooser__24ModalDialog$object *, jboolean) _JC_JCNI_ATTR;
	void	(*show$8844e066fe447d0e)(_jc_env *, struct _jc_javax_swing_JColorChooser__24ModalDialog$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JColorChooser__24ModalDialog$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_java_awt_Window$vmethods	java_awt_Window;
	_jc_java_awt_Dialog$vmethods	java_awt_Dialog;
	_jc_javax_swing_JDialog$vmethods	javax_swing_JDialog;
	_jc_javax_swing_JColorChooser__24ModalDialog$vmethods	javax_swing_JColorChooser__24ModalDialog;
};

// Vtype
struct _jc_javax_swing_JColorChooser__24ModalDialog$vtype {
	_jc_type			type;
	_jc_javax_swing_JColorChooser__24ModalDialog$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JColorChooser__24ModalDialog$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_JColorChooser__24ModalDialog$refs {
    _jc_javax_swing_JColorChooser__24ModalDialog$sub_refs	javax_swing_JColorChooser__24ModalDialog;
    _jc_javax_swing_JDialog$sub_refs	javax_swing_JDialog;
    _jc_java_awt_Dialog$sub_refs	java_awt_Dialog;
    _jc_java_awt_Window$sub_refs	java_awt_Window;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JColorChooser__24ModalDialog$sub_nonrefs {
	jboolean	modal;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JColorChooser__24ModalDialog$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_java_awt_Window$sub_nonrefs	java_awt_Window;
    _jc_java_awt_Dialog$sub_nonrefs	java_awt_Dialog;
    _jc_javax_swing_JDialog$sub_nonrefs	javax_swing_JDialog;
    _jc_javax_swing_JColorChooser__24ModalDialog$sub_nonrefs	javax_swing_JColorChooser__24ModalDialog;
};

// Object instance structure
struct _jc_javax_swing_JColorChooser__24ModalDialog$object {
	_jc_javax_swing_JColorChooser__24ModalDialog$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JColorChooser__24ModalDialog$vtype	*vtype;
	_jc_javax_swing_JColorChooser__24ModalDialog$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JColorChooser__24ModalDialog$vtype _jc_javax_swing_JColorChooser__24ModalDialog$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JColorChooser__24ModalDialog, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JColorChooser__24ModalDialog$class_object;

#endif	/* _JC_javax_swing_JColorChooser__24ModalDialog_H_ */
